@@ -19,9 +19,28 @@ use UNIVERSAL::require;
 use List::Util qw ( max min sum );
 use Sort::Key::Natural qw( natsort natkeysort );
 
+our $VERSION = '2.055'; # VERSION
+
 use overload '""' => \&sprint;
 
-our $VERSION = '2.046'; # VERSION
+my $_defaults = {};   # class variable
+
+sub defaults {
+    my ($self) = @_;
+
+    my $name = ref $self || $self;
+    $_defaults->{$name} ||= {};  # a hash for each sub-class
+    return $_defaults->{$name};
+}
+
+sub import {
+    my ($class, %hash) = @_;
+
+    my $defaults = $class->defaults();
+    while (my ($key, $value) = each %hash) {
+        $defaults->{$key} = $value;
+    }
+}
 
 sub check_coderef { die 'Not a CODE ref' if (ref $_[0] ne 'CODE') };
 sub check_hashref { die 'Not a HASH ref' if (ref $_[0] ne 'HASH') };
@@ -105,6 +124,14 @@ has extra => (      # a little something extra...
     is => 'rw',
 );
 
+sub BUILD {
+    my ($self) = @_;
+
+    while (my ($key, $value) = each %{$self->defaults}) {
+        $self->$key($value);
+    }
+}
+
 sub child_by_name { # find child by name(s), follow down the tree
     my ($self, @names) = @_;
 
@@ -463,11 +490,11 @@ Logwatch::RecordTree - an object to collect and print Logwatch events
 
 =head1 VERSION
 
-version 2.046
+version 2.055
 
 =head1 SYNOPSIS
 
- use Logwatch::RecordTree;
+ use Logwatch::RecordTree ( %options );
 
  my $tree = Logwatch::RecordTree->new( name => 'Service', ... );
 
@@ -499,6 +526,9 @@ which can be used when events should be keyed and sorted by IP number.
 B<Logwatch::RecordTree> overloads the stringification operator via the
 B<sprint> method.
 
+B<%options> specified at 'use' time are added to the B<defaults> option
+hash (see B<defaults> method below).
+
 Example service scripts for dovecot, exim, and http-error (Apache's
 error_log) are provided in the extra/ subdirectory.  These scripts would be
 placed in the /etc/logwatch/services/scripts directory according to the
@@ -629,13 +659,23 @@ any scalar or object.
 =back
 
 In the following methods, either B<$tree> or B<$item> is used as the
-object reference.  B<$item> indicates that the particular item at
-that point of the RecordTree is affected.  B<$tree> indicates that
-the method is inherently recursive and may descend down through the
-RecordTree.
+object reference.  B<$item> indicates that the particular item at that
+point of the RecordTree is affected.  B<$tree> indicates that the method
+affects the entire tree, either through class variables or because the
+method is inherently recursive and may descend down through the RecordTree.
 
 =over
 
+=item $tree->defaults
+
+Returns a reference to a hash of default options.  This hash is a class
+variable, used for all instances, but each sub-class gets its own
+independant hash.
+
+The keys of the hash are the option/method names and the values are the
+default values to be used when a B<new> instance is created.  Any options
+specified in the 'use' directive are added to the hash.
+
 =item $tree->child_by_name (@path)
 
 Find and return the child by following the B<name>s in B<path>.  Returns undef
